@@ -19,6 +19,7 @@ nothing more'''
 #    along with emesene; if not, write to the Free Software
 #    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
+import extension
 import e3
 import gui
 import MarkupParser
@@ -39,6 +40,7 @@ class Conversation(object):
         self.emcache = self.caches.get_emoticon_cache(self.session.account.account)
 
         self.cid = float(cid)
+        self.icid = self.cid
         self.formatter = e3.common.MessageFormatter(session.contacts.me)
         self.first = True
 
@@ -63,6 +65,77 @@ class Conversation(object):
         self.info = None
         self.input = None
         self.output = None
+        self.soundPlayer = extension.get_and_instantiate('sound', session)
+
+    def subscribe_signals(self):
+        ''' subscribes current session's signals '''
+        self.session.config.subscribe(self._on_avatarsize_changed,
+            'i_conv_avatar_size')
+        self.session.config.subscribe(self._on_show_toolbar_changed,
+            'b_show_toolbar')
+        self.session.config.subscribe(self._on_show_header_changed,
+            'b_show_header')
+        self.session.config.subscribe(self._on_show_info_changed,
+            'b_show_info')
+        self.session.config.subscribe(self._on_show_avatar_onleft,
+            'b_avatar_on_left')
+        self.session.config.subscribe(self._on_icon_size_change,
+            'b_toolbar_small')
+        self.session.signals.picture_change_succeed.subscribe(
+            self.on_picture_change_succeed)
+        self.session.signals.contact_attr_changed.subscribe(
+            self.on_contact_attr_changed_succeed)
+
+        self.session.signals.filetransfer_invitation.subscribe(
+                self.on_filetransfer_invitation)
+        self.session.signals.filetransfer_accepted.subscribe(
+                self.on_filetransfer_accepted)
+        self.session.signals.filetransfer_progress.subscribe(
+                self.on_filetransfer_progress)
+        self.session.signals.filetransfer_completed.subscribe(
+                self.on_filetransfer_completed)
+        self.session.signals.filetransfer_rejected.subscribe(
+                self.on_filetransfer_rejected)
+        self.session.signals.filetransfer_canceled.subscribe(
+                self.on_filetransfer_canceled)
+
+        self.session.signals.call_invitation.subscribe(
+                self.on_call_invitation)
+
+    def unsubscribe_signals(self):
+        ''' unsubscribes current session's signals '''
+        self.session.config.unsubscribe(self._on_avatarsize_changed,
+            'i_conv_avatar_size')
+        self.session.config.unsubscribe(self._on_show_toolbar_changed,
+            'b_show_toolbar')
+        self.session.config.unsubscribe(self._on_show_header_changed,
+            'b_show_header')
+        self.session.config.unsubscribe(self._on_show_info_changed,
+            'b_show_info')
+        self.session.config.unsubscribe(self._on_show_avatar_onleft,
+            'b_avatar_on_left')
+        self.session.config.unsubscribe(self._on_icon_size_change,
+            'b_toolbar_small')
+        self.session.signals.picture_change_succeed.unsubscribe(
+            self.on_picture_change_succeed)
+        self.session.signals.contact_attr_changed.unsubscribe(
+            self.on_contact_attr_changed_succeed)
+
+        self.session.signals.filetransfer_invitation.unsubscribe(
+                self.on_filetransfer_invitation)
+        self.session.signals.filetransfer_accepted.unsubscribe(
+                self.on_filetransfer_accepted)
+        self.session.signals.filetransfer_progress.unsubscribe(
+                self.on_filetransfer_progress)
+        self.session.signals.filetransfer_completed.unsubscribe(
+                self.on_filetransfer_completed)
+        self.session.signals.filetransfer_rejected.unsubscribe(
+                self.on_filetransfer_rejected)
+        self.session.signals.filetransfer_canceled.unsubscribe(
+                self.on_filetransfer_canceled)
+
+        self.session.signals.call_invitation.unsubscribe(
+                self.on_call_invitation)
 
     def _get_style(self):
         '''return the value of style'''
@@ -165,9 +238,9 @@ class Conversation(object):
     def on_notify_attention(self):
         '''called when the nudge button is clicked'''
         self.session.request_attention(self.cid)
-        self.output.send_message(self.formatter, self.session.contacts.me,
-                                 '', {}, '', None, self.first,
-                                 e3.Message.TYPE_NUDGE)
+        message = e3.Message(e3.Message.TYPE_NUDGE, '', None, None)
+        message.body = _('You just sent a nudge!')
+        self.output.information(self.formatter, self.session.contacts.me, message)
 
         self.play_nudge()
 
@@ -203,6 +276,14 @@ class Conversation(object):
         """
         raise NotImplementedError("Method not implemented")
 
+    def set_sensitive(self, is_sensitive):
+        """
+        used to make the conversation insensitive while the conversation
+        is still open while the user is disconnected and to set it back to
+        sensitive when the user is reconnected
+        """
+        raise NotImplementedError("Method not implemented")
+
     def set_image_visible(self, is_visible):
         """
         set the visibility of the widget that displays the images of the members
@@ -256,15 +337,16 @@ class Conversation(object):
 
         return len(self.members) > 1
 
-    group_chat = property(fget=_get_group_chat)
+    is_group_chat = property(fget=_get_group_chat)
 
     def _on_send_message(self, text):
         '''method called when the user press enter on the input text'''
         custom_emoticons = gui.base.MarkupParser.get_custom_emotes(text, self.emcache.parse())
 
         self.session.send_message(self.cid, text, self.cstyle, self.emcache.parse(), custom_emoticons)
+        message = e3.Message(e3.Message.TYPE_MESSAGE, text, None, self.cstyle)
         self.output.send_message(self.formatter, self.session.contacts.me,
-                                 text, self.emcache.parse(), self.emcache.path, self.cstyle, self.first)
+                                 message, self.emcache.parse(), self.emcache.path, self.first)
         self.messages.push(text)
         self.play_send()
         self.first = False
@@ -286,8 +368,8 @@ class Conversation(object):
             self.play_type()
 
         elif message.type == e3.Message.TYPE_NUDGE:
-            self.output.information(self.formatter, contact,
-                    _('%s just sent you a nudge!') % (contact.display_name,))
+            message.body = _('%s just sent you a nudge!') % (contact.display_name,)
+            self.output.information(self.formatter, contact, message)
             self.play_nudge()
 
         self.first = False
@@ -295,8 +377,10 @@ class Conversation(object):
     def on_send_message_failed(self, errorCode):
         '''method called when a message fails to be delivered'''
         contact = self.session.contacts.me
-        self.output.information(self.formatter, contact, \
-                                _('Error delivering message'))
+        message = e3.Message(e3.Message.TYPE_MESSAGE, '', None, None)
+        message.body = _('Error delivering message')
+        self.output.information(self.formatter, contact, message)
+
         self.first = False
 
     def on_user_typing(self, account):
@@ -309,9 +393,9 @@ class Conversation(object):
             conversation, a group icon on group chat or a waiting icon)
         '''
         if self.message_waiting:
-            icon = gui.theme.new_message
-        elif self.group_chat:
-            icon = gui.theme.group_chat
+            icon = gui.theme.image_theme.new_message
+        elif self.is_group_chat:
+            icon = gui.theme.image_theme.group_chat
         elif len(self.members) == 1:
             contact = self.session.contacts.get(self.members[0])
 
@@ -322,10 +406,10 @@ class Conversation(object):
             else:
                 stat = e3.status.ONLINE
 
-            icon = gui.theme.status_icons.get(stat, e3.status.OFFLINE)
+            icon = gui.theme.image_theme.status_icons.get(stat, e3.status.OFFLINE)
         else:
             log.debug('unknown state on Conversation._get_icon')
-            return gui.theme.connect
+            return gui.theme.image_theme.connect
 
         return icon
 
@@ -333,7 +417,7 @@ class Conversation(object):
 
     def _get_text(self):
         '''return the text that represent the conversation title'''
-        if self.group_chat:
+        if self.is_group_chat:
             text = _('Group chat')
         elif len(self.members) == 1:
             contact = self.session.contacts.get(self.members[0])
@@ -367,14 +451,26 @@ class Conversation(object):
         '''called when a contact joins the conversation'''
         if account not in self.members:
             self.members.append(account)
-
+            contact = self.session.contacts.get(account)
+            if contact and len(self.members) > 1:
+                message = e3.base.Message(e3.base.Message.TYPE_MESSAGE, \
+                _('%s has joined the conversation') % (contact.display_name), \
+                account)
+                self.output.information(self.formatter, contact, message)
         self.update_data()
+        
 
     def on_contact_left(self, account):
-        '''called when a contact lefts the conversation'''
-        if account in self.members and len(self.members) > 1:
+        '''called when a contact leaves the conversation'''
+        if len(self.members) > 1 and account in self.members:
             self.members.remove(account)
             self.update_data()
+            contact = self.session.contacts.get(account)
+            if contact:
+                message = e3.base.Message(e3.base.Message.TYPE_MESSAGE, \
+                _('%s has left the conversation') % (contact.display_name), \
+                account)
+                self.output.information(self.formatter, contact, message)
 
     def on_group_started(self):
         '''called when a group conversation starts'''
@@ -443,21 +539,21 @@ class Conversation(object):
         play the nudge sound
         """
         if self.session.config.b_play_nudge:
-            gui.play(self.session, gui.theme.sound_nudge)
+            self.soundPlayer.play(gui.theme.sound_theme.sound_nudge)
 
     def play_send(self):
         """
         play the send sound
         """
         if self.session.config.b_play_send:
-            gui.play(self.session, gui.theme.sound_send)
+            self.soundPlayer.play(gui.theme.sound_theme.sound_send)
 
     def play_type(self):
         """
         play the receive sound
         """
-        if self.session.config.b_play_type and self.message_waiting:
-            gui.play(self.session, gui.theme.sound_type)
+        if self.session.config.b_play_type:
+            self.soundPlayer.play(gui.theme.sound_theme.sound_type)
 
     def cycle_history(self, change=-1):
         """
@@ -483,4 +579,3 @@ class Conversation(object):
 
     def _member_to_contact(self,member):
         return self.session.contacts.contacts[member]
-
