@@ -17,7 +17,11 @@
 #    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 import os
+import subprocess
+import sys
+import re
 import time
+import urllib
 import webbrowser
 
 import e3.base
@@ -43,6 +47,24 @@ EMESENE_LICENSE = '''    emesene is free software; you can redistribute it and/o
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 '''
 
+EMESENE_VERSION = "2.11.7"
+EMESENE_LAST_STABLE = "2.11.7"
+EMESENE_WEBSITE = "http://www.emesene.org"
+EMESENE_AUTHORS = "marianoguerra & c10ud"
+EMESENE_CONTRIBUTORS = [
+'Riccardo (c10ud) <c10ud.dev@gmail.com>',
+'Mariano Guerra <luismarianoguerra@gmail.com>',
+'arielj <arieljuod@gmail.com>',
+'Stefano Candori <stefanocandori@gmail.com>',
+'4ndreaSt4gi <stagi.andrea@gmail.com>',
+'Davide Lo Re <boyska@gmail.com>',
+'dequis <dx@dxzone.com.ar>',
+'Sven (Sbte) <svenb.linux@gmail.com>',
+'Jose Rostagno <joserostagno@vijona.com.ar>',
+'nenemfromhell <sniper3000@gmail.com>',
+'Gabriele "Whisky" Visconti <visconti.gabriele@gmail.com>',
+]
+
 class MenuHandler(object):
     '''this handler contains all the handlers needed to handle all the
     menu items
@@ -136,6 +158,7 @@ class OptionsHandler(object):
         '''called when the preference button is selected'''
         instance = extension.get_and_instantiate('preferences', self.session)
         if self.session is not instance.session:
+            instance.remove_subscriptions()
             extension.delete_instance('preferences')
             instance = extension.get_and_instantiate('preferences', self.session)
         instance.show()
@@ -155,31 +178,65 @@ class HelpHandler(object):
     def __init__(self, dialog):
         '''constructor'''
         self.dialog = dialog
+        self.debug_window = None
 
     def on_about_selected(self):
         '''called when the about item is selected'''
-        self.dialog.about_dialog('emesene', '2.11.4', 'marianoguerra & c10ud',
+        self.dialog.about_dialog('emesene', EMESENE_VERSION, EMESENE_AUTHORS,
             _('A simple yet powerful instant messaging client'), EMESENE_LICENSE,
-            'http://www.emesene.org', 
-            [ 'Riccardo (c10ud) <c10ud.dev@gmail.com>',
-              'Mariano Guerra <luismarianoguerra@gmail.com>',
-              'arielj <arieljuod@gmail.com>',
-              'Stefano Candori <stefanocandori@gmail.com>',
-              '4ndreaSt4gi <stagi.andrea@gmail.com>',
-              'Davide Lo Re <boyska@gmail.com>',
-              'dequis <dx@dxzone.com.ar>',
-              'Sven (Sbte) <svenb.linux@gmail.com>' ], _('translator-credits'),
-            gui.theme.logo)
+            EMESENE_WEBSITE, EMESENE_CONTRIBUTORS, _('translator-credits'),
+            gui.theme.image_theme.logo)
 
     def on_website_selected(self):
         '''called when the website item is selected'''
-        webbrowser.open("http://www.emesene.org")
+        webbrowser.open(EMESENE_WEBSITE)
 
     def on_debug_selected(self):
         '''called when the preference button is selected'''
-        DebugWindow = extension.get_default('debug window')
-        DebugWindow().show()
+        def debug_close_cb():
+            self.debug_window = None
+        if not self.debug_window:
+            DebugWindow = extension.get_default('debug window')
+            self.debug_window = DebugWindow(debug_close_cb)
+            self.debug_window.show()
 
+    def notify_update(self, ver):
+        self.dialog.information(_("New version available: %(ver)s\nVisit the "
+                    "<a href=\"%(web)s\">emesene website</a> for the "
+                    "latest informations about it.") % {"ver" : ver,
+                    "web" : EMESENE_WEBSITE})
+
+    def on_check_update_selected(self):
+        ''' checks if a new stable version of emesene is available '''
+        if sys.platform == "darwin":
+            subprocess.call(['open', '-a', '/Applications/emesene.app/Contents/Resources/emesene_updater.app'])
+        else:
+            f = urllib.urlopen("https://github.com/emesene/emesene/raw/master/emesene/gui/base/Handler.py")
+            s = f.read()
+            f.close()
+            s = re.findall(r'EMESENE_LAST_STABLE = "(([^"\\]+|\\.)*)"', s)
+            try:
+                loc_ver = EMESENE_VERSION.split(".")
+                rem_ver = s[0][0].split(".") # [("version","version")]
+                if len(rem_ver[2]) > 2:
+                    return # no RCs, BETAs or DEVELs
+                if len(loc_ver[2]) > 2:
+                    self.dialog.information(_("You're running a development version of emesene, "
+                                              "you might want to use the latest stable version "
+                                              "(%s) unless you know what you're doing") % (s[0][0]))
+                    return
+                if int(loc_ver[0]) == int(rem_ver[0]):
+                    if int(loc_ver[1]) < int(rem_ver[1]):
+                        self.notify_update(s[0][0])
+                        return
+                    elif int(loc_ver[1]) == int(rem_ver[1]):
+                        if int(loc_ver[2]) < int(rem_ver[2]):
+                            self.notify_update(s[0][0])
+                            return
+            except IndexError:
+                pass # Silently fail
+
+            self.dialog.information(_("No update available"))
 
 class ContactHandler(object):
     '''this handler contains all the handlers needed to handle the contact
@@ -274,8 +331,8 @@ class ContactHandler(object):
         contact = self.contact_list.get_contact_selected()
 
         if contact:
-            self.dialog.set_contact_alias(contact.account, contact.alias,
-                 set_alias_cb)
+            self.dialog.set_contact_alias(contact.account,
+                    contact.alias if contact.alias != '' else contact.display_name, set_alias_cb)
         else:
             self.dialog.error(_('No contact selected'))
 
@@ -326,6 +383,9 @@ class GroupHandler(object):
         self.dialog = dialog
         self.contact_list = contact_list
 
+    def is_by_group_view(self):
+        return self.contact_list.order_by_group
+
     def on_add_group_selected(self):
         '''called when add group is selected'''
         def add_group_cb(response, group_name):
@@ -375,6 +435,34 @@ class GroupHandler(object):
         else:
             self.dialog.error(_('No group selected'))
 
+    def on_favorite_group_selected(self):
+        ''' called when set as favorite is selected '''
+        group = self.contact_list.get_group_selected()
+
+        if group:
+            # reset old group's weight
+            old_fav_group_id = self.session.config.favorite_group_id
+            if old_fav_group_id is not None:
+                self.session.config.d_weights[old_fav_group_id] = 0
+            # increase new group's weight
+            self.session.config.favorite_group_id = group.identifier
+            self.session.config.d_weights[group.identifier] = 1
+            self.contact_list.fill()
+        else:
+            self.dialog.error(_('No group selected'))
+    
+    def on_unset_favorite_group_selected(self):
+        ''' called when unset as favorite is selected in a favorite group '''
+        group = self.contact_list.get_group_selected()
+        
+        if group:
+            # reset group weight
+            self.session.config.d_weights[group.identifier] = 0
+            self.session.config.favorite_group_id = None
+            self.contact_list.fill()
+        else:
+            self.dialog.error(_('No group selected'))
+
 class MyAccountHandler(object):
     '''this handler contains all the handlers needed to handle the my account
     menu items
@@ -418,6 +506,18 @@ class ConversationToolbarHandler(object):
         self.conversation = conversation
         self.theme = theme
 
+    def session_call_supported(self):
+        '''check if current session supports calls '''
+        user = self.session.account.account
+        current_service = self.session.config.d_user_service.get(user, 'msn')
+        return current_service in ['']
+
+    def session_filetransfer_supported(self):
+        '''check if current session supports file transfers '''
+        user = self.session.account.account
+        current_service = self.session.config.d_user_service.get(user, 'msn')
+        return current_service in ['msn']
+
     def on_font_selected(self):
         '''called when the Font button is selected'''
         self.dialog.select_font(self.conversation.cstyle,
@@ -548,8 +648,9 @@ class CallHandler(object):
 
     def accept(self):
         ''' accepts a call '''
-        self.call.state = e3.base.Call.ESTABLISHED
-        self.session.accept_call(self.call)
+        if self.call.state != e3.base.Call.ESTABLISHED:
+            self.call.state = e3.base.Call.ESTABLISHED
+            self.session.accept_call(self.call)
 
     def accepted(self):
         ''' when a call is accepted by the other party'''
