@@ -51,7 +51,7 @@ class LoginBase(gtk.Alignment):
         completion.set_text_column(0)
         completion.set_inline_selection(True)
 
-        self.pixbuf = utils.safe_gtk_pixbuf_load(gui.theme.user)
+        self.pixbuf = utils.safe_gtk_pixbuf_load(gui.theme.image_theme.user)
 
         self.cmb_account = gtk.ComboBoxEntry(self.liststore, 0)
         self.cmb_account.set_tooltip_text(_('Account'))
@@ -76,8 +76,8 @@ class LoginBase(gtk.Alignment):
         self.txt_password.connect('changed', self._on_password_changed)
         self.txt_password.set_sensitive(False)
 
-        pix_account = utils.safe_gtk_pixbuf_load(gui.theme.user)
-        pix_password = utils.safe_gtk_pixbuf_load(gui.theme.password)
+        pix_account = utils.safe_gtk_pixbuf_load(gui.theme.image_theme.user)
+        pix_password = utils.safe_gtk_pixbuf_load(gui.theme.image_theme.password)
 
         self.avatar = Avatar()
 
@@ -188,7 +188,7 @@ class LoginBase(gtk.Alignment):
 
         self.nicebar = NiceBar()
 
-        th_pix = utils.safe_gtk_pixbuf_load(gui.theme.throbber, None,
+        th_pix = utils.safe_gtk_pixbuf_load(gui.theme.image_theme.throbber, None,
                 animated=True)
         self.throbber = gtk.image_new_from_animation(th_pix)
         self.label_timer = gtk.Label()
@@ -217,14 +217,16 @@ class LoginBase(gtk.Alignment):
         vbox_top = gtk.VBox()
         vbox_far_bottom = gtk.VBox()
 
-        vbox_bottom = gtk.VBox(True)
+        vbox_bottom = gtk.VBox(False)
         vbox_content.pack_start(gtk.Label(""), True, True)
         vbox_content.pack_start(al_account, True, False)
         vbox_content.pack_start(gtk.Label(""), True, True)
         vbox_content.pack_start(al_vbox_entries, False)
         vbox_content.pack_start(al_vbox_remember, True, False)
+        vbox_bottom.set_size_request(-1, 100)
         vbox_bottom.pack_start(al_label_timer, True, False)
         vbox_bottom.pack_start(al_throbber, False)
+        vbox_bottom.pack_start(gtk.Label(""), True, True)
         vbox_bottom.pack_start(al_button)
         vbox_content.pack_start(vbox_bottom)
         vbox_content.pack_start(gtk.Label(""), True, True)
@@ -354,7 +356,7 @@ class Login(LoginBase):
                     session_found = True
 
                 try:
-                    s_name = getattr(gui.theme, "service_" + service_name) 
+                    s_name = getattr(gui.theme.image_theme, "service_" + service_name) 
                     image = utils.safe_gtk_pixbuf_load(s_name)
                 except:
                     image = None
@@ -508,7 +510,7 @@ class Login(LoginBase):
                 self._clear_all()
 
         else:
-           self.avatar.set_from_file(gui.theme.logo)
+           self.avatar.set_from_file(gui.theme.image_theme.logo)
 
     def _clear_all(self):
         '''
