@@ -104,7 +104,7 @@ class MainWindow(gtk.VBox):
         self.session.config.subscribe(self._on_show_userpanel_changed,
             'b_show_userpanel')
 
-    def _on_mail_count_changed(self,count):
+    def _on_mail_count_changed(self, count):
         self.panel.mail.set_label("(%d)" % count)
 
     def _on_mail_click(self, widget, data):
@@ -149,6 +149,7 @@ class MainWindow(gtk.VBox):
         self.below_menu.show()
         self.below_panel.show()
         self.below_userlist.show()
+        self.contact_list._set_accels(self.get_parent())
 
     def _on_entry_changed(self, entry, *args):
         '''called when the text on entry changes'''
@@ -183,6 +184,10 @@ class MainWindow(gtk.VBox):
 
     def _on_group_menu_selected(self, group):
         '''callback for the group-menu-selected signal'''
+        if self.contact_list.is_favorite_group_selected():
+            self.group_menu.show_unset_favorite_item()
+        else:
+            self.group_menu.show_set_favorite_item()
         self.group_menu.popup(None, None, None, 0, 0)
 
     def _on_contact_attr_changed(self, account, change_type, old_value,
@@ -192,16 +197,6 @@ class MainWindow(gtk.VBox):
         if not contact:
             log.debug('account %s not found on contacts' % account)
 
-        if change_type == 'status' and do_notify:
-            if old_value == e3.base.status.OFFLINE and \
-              contact.status != e3.base.status.OFFLINE and \
-              self.session.config.b_play_contact_online:
-                gui.play(self.session, gui.theme.sound_online)
-            elif old_value != e3.base.status.OFFLINE and \
-              contact.status == e3.base.status.OFFLINE and \
-              self.session.config.b_play_contact_offline:
-                gui.play(self.session, gui.theme.sound_offline)
-
     def _on_nick_changed(self, textfield, old_text, new_text):
         '''method called when the nick is changed on the panel'''
         self.session.set_nick(new_text)
@@ -230,8 +225,14 @@ class MainWindow(gtk.VBox):
             self._on_contact_menu_selected)
         self.contact_list.group_menu_selected.unsubscribe(
             self._on_group_menu_selected)
+        self.contact_list.remove_subscriptions()
         self.session.config.unsubscribe(self._on_show_userpanel_changed,
             'b_show_userpanel')
+        self.session.signals.mail_count_changed.unsubscribe(
+            self._on_mail_count_changed)
+        self.session.signals.contact_attr_changed.unsubscribe(
+            self._on_contact_attr_changed)
+        self.panel.remove_subscriptions()
         self.on_disconnect_cb()
 
     def _on_search_toggled(self, button):
