@@ -24,11 +24,14 @@ import utils
 from pluginmanager import get_pluginmanager
 
 class PluginListView(gtk.TreeView):
-    def __init__(self, store):
+    def __init__(self, store, toggle_func=None):
         gtk.TreeView.__init__(self, store)
-        self.append_column(gtk.TreeViewColumn(_('Status'), gtk.CellRendererToggle(), active=0))
+        self.toggle_renderer = gtk.CellRendererToggle()
+        self.append_column(gtk.TreeViewColumn(_('Status'), self.toggle_renderer, active=0))
         self.append_column(gtk.TreeViewColumn(_('Name'), gtk.CellRendererText(), text=1))
         self.set_rules_hint(True)
+        if toggle_func:
+            self.toggle_renderer.connect("toggled", toggle_func)
 
 class PluginListStore(gtk.ListStore):
     def __init__(self):
@@ -58,7 +61,8 @@ class PluginMainVBox(gtk.VBox):
 
         self.plugin_list_store = PluginListStore()
         self.plugin_list_store.update_list()
-        self.plugin_list_view = PluginListView(self.plugin_list_store)
+        self.plugin_list_view = PluginListView(self.plugin_list_store, self.toggle_func)
+        self.plugin_list_view.connect("cursor_changed", self.on_cursor_changed)
 
         scroll = gtk.ScrolledWindow()
         scroll.add(self.plugin_list_view)
@@ -70,26 +74,37 @@ class PluginMainVBox(gtk.VBox):
         button_hbox.set_layout(gtk.BUTTONBOX_END)
         button_hbox.set_border_width(2)
 
-        button_start = gtk.Button(stock=gtk.STOCK_EXECUTE)
-        button_start.connect('clicked', self.on_start)
+        self.button_start = gtk.Button(stock=gtk.STOCK_EXECUTE)
+        self.button_start.connect('clicked', self.on_start)
 
-        button_stop = gtk.Button(stock=gtk.STOCK_STOP)
-        button_stop.connect('clicked', self.on_stop)
+        self.button_stop = gtk.Button(stock=gtk.STOCK_STOP)
+        self.button_stop.connect('clicked', self.on_stop)
+        self.button_stop.hide()
 
         button_config = gtk.Button(stock=gtk.STOCK_PREFERENCES)
         button_config.connect('clicked', self.on_config)
 
         self.pack_start(scroll)
         button_hbox.pack_start(button_config, fill=False)
-        button_hbox.pack_start(button_start, fill=False)
-        button_hbox.pack_start(button_stop, fill=False)
+        button_hbox.pack_start(self.button_start, fill=False)
+        button_hbox.pack_start(self.button_stop, fill=False)
         self.pack_start(button_hbox, False)
+        self.on_cursor_changed(self.plugin_list_view)
+
+    def toggle_func(self, toggle, path):
+        '''called when the toggle button in list view is pressed'''
+        sel = self.plugin_list_view.get_selection()
+        sel.select_path(path)
+        if not toggle.get_active():
+            self.on_start()
+        else:
+            self.on_stop()
 
     def on_start(self, *args):
         '''start the selected plugin'''
         sel = self.plugin_list_view.get_selection()
         model, iter = sel.get_selected()
-        if iter != None:
+        if iter is not None:
             name = model.get_value(iter, 2)
             pluginmanager = get_pluginmanager()
             pluginmanager.plugin_start(name, self.session)
@@ -98,12 +113,13 @@ class PluginMainVBox(gtk.VBox):
                 self.session.config.l_active_plugins.append(name)
 
             model.set_value(iter, 0, bool(pluginmanager.plugin_is_active(name)))
+        self.on_cursor_changed(self.plugin_list_view)
 
     def on_stop(self, *args):
         '''stop the selected plugin'''
         sel = self.plugin_list_view.get_selection()
         model, iter = sel.get_selected()
-        if iter != None:
+        if iter is not None:
             name = model.get_value(iter, 2)
             pluginmanager = get_pluginmanager()
             pluginmanager.plugin_stop(name)
@@ -112,12 +128,13 @@ class PluginMainVBox(gtk.VBox):
                 self.session.config.l_active_plugins.remove(name)
 
             model.set_value(iter, 0, pluginmanager.plugin_is_active(name))
+        self.on_cursor_changed(self.plugin_list_view)
 
     def on_config(self, *args):
         '''stop the selected plugin'''
         sel = self.plugin_list_view.get_selection()
         model, iter = sel.get_selected()
-        if iter != None:
+        if iter is not None:
             name = model.get_value(iter, 2)
             pluginmanager = get_pluginmanager()
 
@@ -127,6 +144,17 @@ class PluginMainVBox(gtk.VBox):
     def on_update(self):
         pass
 
+    def on_cursor_changed(self, plugin_list_view):
+        model, iter = plugin_list_view.get_selection().get_selected()
+        if iter is not None:
+          value = model.get_value(iter,0)
+          if value:
+              self.button_stop.show()
+              self.button_start.hide()
+          else:
+              self.button_stop.hide()
+              self.button_start.show()
+
 class PluginWindow(gtk.Window):
     def __init__(self, session):
         gtk.Window.__init__(self, gtk.WINDOW_TOPLEVEL)
@@ -140,5 +168,3 @@ class PluginWindow(gtk.Window):
 
         self.add(self.main_vbox)
         self.show_all()
-
-
