@@ -61,21 +61,16 @@ class Preferences(gtk.Window):
         self.session = session
 
         self.set_default_size(600, 400)
-        # GNOME3 likes to break things..was WINDOW_TYPE_HINT_DIALOG
-        self.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_MENU)
+        self.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_DIALOG)
 
         ''' TREE VIEW STUFF '''
         # Create the list store model for the treeview.
-        listStore = gtk.ListStore(gtk.gdk.Pixbuf, str)
+        self.listStore = gtk.ListStore(gtk.gdk.Pixbuf, str)
+
 
-        for i in LIST:
-            # we should use always the same icon size,
-            # we can remove that field in LIST
-            listStore.append([self.render_icon(i['stock_id'],
-                             gtk.ICON_SIZE_LARGE_TOOLBAR), i['text']])
 
         # Create the TreeView
-        treeView = gtk.TreeView(listStore)
+        treeView = gtk.TreeView(self.listStore)
 
         # Create the renders
         cellText = gtk.CellRendererText()
@@ -123,6 +118,8 @@ class Preferences(gtk.Window):
         self.close.connect('clicked', lambda *args: self.hide())
         self.buttons.pack_start(self.close)
 
+        vbox.pack_start(self.buttons, False, False)
+
         # Create a dict that stores each page
         self.page_dict = []
 
@@ -135,6 +132,34 @@ class Preferences(gtk.Window):
         self.extensions_page = self.extension
         self.plugins_page = self.plugins
 
+        self.__init_list()
+
+        self.connect('delete_event', self.hide_on_delete)
+        self.add(vbox)
+        vbox.show_all()
+
+    def remove_subscriptions(self):
+        self.interface.remove_subscriptions()
+        self.sound.remove_subscriptions()
+        self.theme.remove_subscriptions()
+
+    def remove_from_list(self, icon, text, page):
+
+        LIST.remove({'stock_id' : icon,'text' : text})
+        self.page_dict.remove(page)
+        num = self.notebook.page_num(page)
+        self.notebook.remove_page(num)
+        self.__refresh_list()    
+
+    def add_to_list(self, icon, text, page):
+
+        LIST.append({'stock_id' : icon,'text' : text})
+        self.page_dict.append(page)
+        self.notebook.append_page(page)
+        self.__refresh_list()
+
+    def __init_list(self):
+
         # Whack the pages into a dict for future reference
 
         self.page_dict.append(self.interface_page)
@@ -145,19 +170,32 @@ class Preferences(gtk.Window):
         self.page_dict.append(self.extensions_page)
         self.page_dict.append(self.plugins_page)
 
+        for i in LIST:
+            # we should use always the same icon size,
+            # we can remove that field in LIST
+            self.listStore.append([self.render_icon(i['stock_id'],
+                             gtk.ICON_SIZE_LARGE_TOOLBAR), i['text']])
+
         if 'msn' in self.session.SERVICES: # only when session is papylib.
-            listStore.append([self.render_icon(gtk.STOCK_NETWORK,
+            LIST.append({'stock_id' : gtk.STOCK_NETWORK,'text' : _('Live Messenger')})
+            self.listStore.append([self.render_icon(gtk.STOCK_NETWORK,
                              gtk.ICON_SIZE_LARGE_TOOLBAR), _('Live Messenger')])
-            self.msn_papylib = MSNPapylib(session)
+            self.msn_papylib = MSNPapylib(self.session)
             self.msn_papylib_page = self.msn_papylib
             self.page_dict.append(self.msn_papylib_page)
 
         for i in range(len(self.page_dict)):
            self.notebook.append_page(self.page_dict[i])
 
-        self.connect('delete_event', self.hide_on_delete)
-        self.add(vbox)
-        vbox.show_all()
+    def __refresh_list(self):
+
+        self.listStore.clear()
+
+        for i in LIST:
+            # we should use always the same icon size,
+            # we can remove that field in LIST
+            self.listStore.append([self.render_icon(i['stock_id'],
+                             gtk.ICON_SIZE_LARGE_TOOLBAR), i['text']])
 
     def _on_row_activated(self,treeview):
         # Get information about the row that has been selected
@@ -316,19 +354,11 @@ class BaseTable(gtk.Table):
 
         self.append_row(hbox, None)
 
-    def create_combo_with_label(self, text, getter, property_name,values=None):
-        """creates and return a new ComboBox with a label and append values to the combo
-        """
+    def fill_combo(self, combo, getter, property_name, values=None):
         if values:
             default = getter()[values.index(self.get_attr(property_name))]
         else:
             default = self.get_attr(property_name)
-        hbox = gtk.HBox()
-        hbox.set_homogeneous(True)
-        label = gtk.Label(text)
-        label.set_alignment(0.0, 0.5)
-        combo = gtk.combo_box_new_text()
-
         count = 0
         default_count = 0
         for item in getter():
@@ -340,11 +370,27 @@ class BaseTable(gtk.Table):
 
         combo.set_active(default_count)
 
+    def create_combo (self, getter, property_name, values=None, changed_cb = None):
+        combo = gtk.combo_box_new_text()
+        self.fill_combo(combo, getter, property_name, values)
+        if changed_cb:
+            combo.connect('changed', changed_cb, property_name, values)
+        else:
+            combo.connect('changed', self.on_combo_changed, property_name, values)
+        return combo
+
+    def create_combo_with_label(self, text, getter, property_name,values=None, changed_cb = None):
+        """creates and return a new ComboBox with a label and append values to the combo
+        """
+        hbox = gtk.HBox()
+        hbox.set_homogeneous(True)
+        label = gtk.Label(text)
+        label.set_alignment(0.0, 0.5)
+        combo = self.create_combo(getter, property_name, values, changed_cb)
+
         hbox.pack_start(label, True, True)
         hbox.pack_start(combo, False)
 
-        combo.connect('changed', self.on_combo_changed, property_name, values)
-
         return hbox
 
     def append_combo(self, text, getter, property_name,values=None):
@@ -419,6 +465,9 @@ class BaseTable(gtk.Table):
         """try to get the value of the attribute 'name' from obj, if it
         doesn't exist return default"""
         if not hasattr(obj, name):
+            if hasattr(obj, 'func_globals') and name in obj.func_globals.keys():
+                return obj.func_globals[name]
+
             return default
 
         return getattr(obj, name)
@@ -436,7 +485,7 @@ class BaseTable(gtk.Table):
         """called when the Synch test button is clicked"""
         syn = extension.get_default('synch tool')
         user = self.session.account.account
-        current_service = self.session.config.d_user_service.get(user, 'msn')
+        current_service = self.session.config.service
         syn = syn(self.session, current_service)
         syn.show(True)
 
@@ -560,6 +609,16 @@ class Interface(BaseTable):
     def get_tab_positions(self):
         return [_("Top"),_("Bottom"),_("Left"),_("Right")]
 
+    def remove_subscriptions(self):
+        self.session.config.unsubscribe(self._on_cb_show_toolbar_changed,
+            'b_show_toolbar')
+        self.session.config.unsubscribe(self._on_cb_side_panel_changed,
+            'b_show_info')
+        self.session.config.unsubscribe(self._on_spell_change,
+            'b_enable_spell_check')
+        self.session.config.unsubscribe(self._on_conversation_tabs_change,
+            'b_conversation_tabs')
+
 class Sound(BaseTable):
     """the panel to display/modify the config related to the sounds
     """
@@ -603,6 +662,10 @@ class Sound(BaseTable):
             else:
                 i.set_sensitive(True)
 
+    def remove_subscriptions(self):
+        self.session.config.unsubscribe(self._on_mute_sounds_changed,
+            'b_mute_sounds')
+
 class Notification(BaseTable):
     """the panel to display/modify the config related to the notifications
     """
@@ -630,7 +693,7 @@ class Theme(BaseTable):
     def __init__(self, session):
         """constructor
         """
-        BaseTable.__init__(self, 5, 1)
+        BaseTable.__init__(self, 6, 1)
         self.set_border_width(5)
         self.session = session
 
@@ -638,7 +701,8 @@ class Theme(BaseTable):
 
         self.session.config.get_or_set('adium_theme', 'renkoo')
 
-        cb_override_text_color = self.create_check(_('Override incoming text color'), 'session.config.b_override_text_color')
+        cb_override_text_color = self.create_check(_('Override incoming text color'),
+            'session.config.b_override_text_color')
         self.session.config.subscribe(self._on_cb_override_text_color_toggled,
             'b_override_text_color')
 
@@ -657,7 +721,8 @@ class Theme(BaseTable):
 
         self.append_row(h_color_box)
         #update ColorButton sensitive
-        self._on_cb_override_text_color_toggled(self.session.config.get_or_set('b_override_text_color', False))
+        self._on_cb_override_text_color_toggled(
+                self.session.config.get_or_set('b_override_text_color', False))
 
         self.append_combo(_('Image theme'), gui.theme.get_image_themes,
             'session.config.image_theme')
@@ -665,22 +730,53 @@ class Theme(BaseTable):
             'session.config.sound_theme')
         self.append_combo(_('Emote theme'), gui.theme.get_emote_themes,
             'session.config.emote_theme')
-        self.append_combo(_('Adium theme'), gui.theme.get_adium_themes,
-            'session.config.adium_theme')
+        self.adium_theme_combo = self.create_combo_with_label(_('Adium theme'),
+                gui.theme.get_adium_themes, 'session.config.adium_theme',
+                changed_cb = self._on_adium_theme_combo_changed)
+        self.append_row(self.adium_theme_combo)
+        hbox = gtk.HBox()
+        hbox.set_homogeneous(True)
+        label = gtk.Label(_('Adium theme variant'))
+        label.set_alignment(0.0, 0.5)
+        self.adium_variant_combo = self.create_combo(gui.theme.conv_theme.get_theme_variants,
+                'session.config.adium_theme_variant')
+        hbox.pack_start(label, True, True)
+        hbox.pack_start(self.adium_variant_combo, False)
+        self.append_row(hbox, None)
+
         self.append_entry_default(_('Nick format'), 'nick',
                 'session.config.nick_template_clist', ContactList.NICK_TPL)
         self.append_entry_default(_('Group format'), 'group',
                 'session.config.group_template', ContactList.GROUP_TPL)
 
-        self.add_button(_('Apply'), 0, 7,
+        self.add_button(_('Apply'), 0, 8,
                 self.on_redraw_main_screen, 0, 0)
 
+    def _on_adium_theme_combo_changed(self, combo, property_name, values=None):
+        #update adium variants combo
+        self.on_combo_changed(combo, property_name, values)
+
+        image_name = self.session.config.get_or_set('image_theme', 'default')
+        emote_name = self.session.config.get_or_set('emote_theme', 'default')
+        sound_name = self.session.config.get_or_set('sound_theme', 'default')
+        conv_name = self.session.config.get_or_set('adium_theme',
+                'renkoo.AdiumMessagesStyle')
+        gui.theme.set_theme(image_name, emote_name, sound_name, conv_name)
+        #clear combo
+        self.adium_variant_combo.get_model().clear()
+        self.fill_combo(self.adium_variant_combo,
+            gui.theme.conv_theme.get_theme_variants, 'session.config.adium_theme_variant')
+
     def _on_cb_override_text_color_toggled(self, value):
         if value:
             self.b_text_color.set_sensitive(True)
         else:
             self.b_text_color.set_sensitive(False)
 
+    def remove_subscriptions(self):
+        self.session.config.unsubscribe(self._on_cb_override_text_color_toggled,
+            'b_override_text_color')
+
 class Extension(BaseTable):
     """the panel to display/modify the config related to the extensions
     """
@@ -708,6 +804,10 @@ class Extension(BaseTable):
         """add the widgets that will display the information of the extension
         category and the selected extension
         """
+        def on_activate_link(label, uri):
+            webbrowser.open_new_tab(uri)
+            return True
+        
         self.add_text(_('Categories'), 0, 0, True)
         self.add_text(_('Selected'), 0, 1, True)
         self.add_text('', 0, 2, True)
@@ -720,6 +820,7 @@ class Extension(BaseTable):
         self.description_info.set_width_chars(40)
         self.add_label(self.description_info, 1, 4, True)
         self.add_label(self.author_info, 1, 5, True)
+        self.website_info.connect('activate-link', on_activate_link)
         self.add_label(self.website_info, 1, 6, True)
 
         self.add_text('', 0, 7, True)
@@ -745,13 +846,15 @@ class Extension(BaseTable):
             self.categories.append_text(item)
 
         self.categories.connect('changed', self._on_category_changed)
-        self.extensions.connect('changed', self._on_extension_changed)
+        self.ext_id = self.extensions.connect('changed',
+                                              self._on_extension_changed)
         self.attach(self.categories, 1, 2, 0, 1, yoptions=0)
         self.attach(self.extensions, 1, 2, 1, 2, yoptions=0)
         self.categories.set_active(0)
 
     def _on_category_changed(self, combo):
         """callback called when the category on the combo changes"""
+        self.extensions.disconnect(self.ext_id)
         self.extensions.get_model().clear()
         self.extension_list = []
         category = combo.get_active_text()
@@ -770,6 +873,9 @@ class Extension(BaseTable):
             count += 1
 
         self.extensions.set_active(selected)
+        self.ext_id = self.extensions.connect('changed',
+                                              self._on_extension_changed)
+        self._on_extension_changed(self.extensions)
 
     def _on_extension_changed(self, combo):
         """callback called when the extension on the combo changes"""
@@ -787,6 +893,8 @@ class Extension(BaseTable):
                 (extension_index, category))
             return
         else:
+            if self.session.config.d_extensions is None:
+                self.session.config.d_extensions = {}
             self.session.config.d_extensions[category] = identifier
 
         ext = extension.get_default(category)
@@ -830,10 +938,13 @@ class DesktopTab(BaseTable):
         self.set_border_width(5)
         self.session = session
 
+        self.append_markup('<b>'+_('Logger')+'</b>')
+        self.append_check(_('Enable logger'), 
+                          'session.config.b_log_enabled')
         self.append_markup('<b>'+_('File transfers')+'</b>')
         self.append_check(_('Sort received files by sender'), 
                           'session.config.b_download_folder_per_account')
-        self.add_text(_('Save files to:'), 0, 2, True)
+        self.add_text(_('Save files to:'), 0, 4, True)
 
         def on_path_selected(f_chooser):
             ''' updates the download dir config value '''
@@ -848,9 +959,8 @@ class DesktopTab(BaseTable):
         fc_button = gtk.FileChooserButton(path_chooser)
         fc_button.set_current_folder(self.session.config.get_or_set("download_folder", \
                 e3.common.locations.downloads()))
-        path_chooser.connect('selection-changed', on_path_selected)
-        self.attach(fc_button, 2, 3, 2, 3, gtk.EXPAND|gtk.FILL, 0)
-
+        fc_button.connect('selection-changed', on_path_selected)
+        self.attach(fc_button, 2, 3, 4, 5, gtk.EXPAND|gtk.FILL, 0)
 
 class MSNPapylib(BaseTable):
     """ This panel contains some msn-papylib specific settings """
