@@ -35,19 +35,23 @@ class Window(gtk.Window):
 
         self.set_location(width, height, posx, posy)
         self.set_title("emesene")
+        image_theme = gui.theme.image_theme
         try:
             gtk.window_set_default_icon_list(\
-                 utils.safe_gtk_image_load(gui.theme.logo16).get_pixbuf(), \
-                 utils.safe_gtk_image_load(gui.theme.logo32).get_pixbuf(), \
-                 utils.safe_gtk_image_load(gui.theme.logo48).get_pixbuf(), \
-                 utils.safe_gtk_image_load(gui.theme.logo96).get_pixbuf())
+                 utils.safe_gtk_image_load(image_theme.logo16).get_pixbuf(), \
+                 utils.safe_gtk_image_load(image_theme.logo32).get_pixbuf(), \
+                 utils.safe_gtk_image_load(image_theme.logo48).get_pixbuf(), \
+                 utils.safe_gtk_image_load(image_theme.logo96).get_pixbuf())
         except:
-            self.gtk.window_set_default_icon(gui.theme.logo)
+            gtk.window_set_default_icon(image_theme.logo)
 
         self.cb_on_close = cb_on_close
+        self.cb_on_quit = cb_on_close
+        self._state = 0
 
         self.connect('delete-event', self._on_delete_event)
         self.connect('key-press-event', self._on_key_press)
+        self.connect('window-state-event', self._on_window_state_event)
         self.content = None
 
         self.content_type = 'empty'
@@ -91,7 +95,7 @@ class Window(gtk.Window):
         self.content_type = 'connecting'
 
     def go_main(self, session, on_new_conversation,
-            on_close, on_disconnect):
+            on_close, on_disconnect, quit_on_close=False):
         '''change to the main window'''
         MainWindow = extension.get_default('main window')
         self.content = MainWindow(session, on_new_conversation,
@@ -101,7 +105,10 @@ class Window(gtk.Window):
         self.content_type = 'main'
 
         # hide the main window only when the user is connected
-        self.cb_on_close = lambda *args: self.hide_on_delete()
+        if quit_on_close:
+            self.cb_on_close = self.cb_on_quit
+        else:
+            self.cb_on_close = lambda *args: self.hide_on_delete()
 
     def on_disconnect(self, cb_on_close):
         '''called when the user is disconnected'''
@@ -113,6 +120,7 @@ class Window(gtk.Window):
         self.content = ConversationManager(session, self._on_last_tab_close)
         self.add(self.content)
         self.connect('focus-in-event', self.content._on_focus)
+        self.connect('key-press-event', self.content._on_key_press)
         self.content.show()
         self.content_type = 'conversation'
         self.content._set_accels()
@@ -185,3 +193,12 @@ class Window(gtk.Window):
         gtk.Window.show(self)
         self.set_location()
 
+    def _on_window_state_event(self, window, state):
+        '''callew when window state is changed
+        '''
+        self._state = state.new_window_state if state.new_window_state & gtk.gdk.WINDOW_STATE_WITHDRAWN == 0 else self._state
+
+    def is_maximized(self):
+        '''return True is window is maximized, False otherwise
+        '''
+        return self._state & gtk.gdk.WINDOW_STATE_MAXIMIZED == gtk.gdk.WINDOW_STATE_MAXIMIZED
